#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LOAD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LOAD_HPP_INCLUDED

#include <boost/simd/memory/include/functions/load.hpp>

#endif
